@@ -20,7 +20,7 @@ use Module::Install::Base;
               &get_bzip2_version
             );
 
-$VERSION = sprintf "%d.%02d%02d", q/0.30.3/ =~ /(\d+)/g;
+$VERSION = sprintf "%d.%02d%02d", q/0.30.6/ =~ /(\d+)/g;
 
 # ---------------------------------------------------------------------------
 
@@ -201,7 +201,7 @@ sub _prompt_user_for_program_locations
 
     my $choice = $self->prompt(
       "Where can I find your \"$program_name\" executable?" .
-      "$allowed_types" => $full_path);
+      "$allowed_types", $full_path);
 
     $program_info{$program_name} =
       { path => undef, type => undef, version => undef }, next
@@ -361,7 +361,6 @@ sub _Make_Absolute
 
 sub get_gnu_version
 {
-  my $self = shift;
   my $program = shift;
 
   die "Missing GNU program to get version for" unless defined $program;
@@ -393,7 +392,6 @@ sub get_gnu_version
 
 sub get_bzip2_version
 {
-  my $self = shift;
   my $program = shift;
 
   my $command = "$program --help 2>&1 1>" . File::Spec->devnull();
@@ -408,4 +406,4 @@ sub get_bzip2_version
 
 # ---------------------------------------------------------------------------
 
-#line 632
+#line 629
