@@ -54,483 +54,483 @@ sub new {
 	{#State 0
 		DEFAULT => -3,
 		GOTOS => {
-			'input' => 1,
-			'declarations' => 2
+			'declarations' => 1,
+			'input' => 2
 		}
 	},
 	{#State 1
 		ACTIONS => {
-			'' => 3
+			'PERCENT_VERBOSE' => 7,
+			'PROLOGUE' => 5,
+			'PERCENT_TOKEN' => 6,
+			'PERCENT_DEBUG' => 4,
+			'PERCENT_EXPECT' => 3,
+			'PERCENT_NONASSOC' => 15,
+			'SEMICOLON' => 12,
+			'PERCENT_YACC' => 10,
+			"%%" => 11,
+			'PERCENT_FILE_PREFIX' => 9,
+			'PERCENT_RIGHT' => 8,
+			'PERCENT_TYPE' => 20,
+			'PERCENT_TOKEN_TABLE' => 19,
+			'PERCENT_UNION' => 18,
+			'PERCENT_DEFINES' => 27,
+			'PERCENT_NAME_PREFIX' => 30,
+			'PERCENT_START' => 28,
+			'PERCENT_PURE_PARSER' => 26,
+			'PERCENT_NO_LINES' => 25,
+			'PERCENT_LOCATIONS' => 24,
+			'PERCENT_OUTPUT' => 23,
+			'PERCENT_PARSE_PARAM' => 21,
+			'PERCENT_LEFT' => 22
+		},
+		GOTOS => {
+			'precedence_declarator' => 16,
+			'symbol_declaration' => 17,
+			'precedence_declaration' => 13,
+			'grammar_declaration' => 29,
+			'declaration' => 14
 		}
 	},
 	{#State 2
 		ACTIONS => {
-			'PERCENT_DEBUG' => 8,
-			'PERCENT_UNION' => 7,
-			'SEMICOLON' => 4,
-			'PERCENT_LOCATIONS' => 6,
-			'PERCENT_PURE_PARSER' => 5,
-			'PERCENT_NONASSOC' => 13,
-			'PERCENT_RIGHT' => 12,
-			'PERCENT_TYPE' => 9,
-			'PERCENT_TOKEN' => 21,
-			'PERCENT_YACC' => 20,
-			'PERCENT_OUTPUT' => 18,
-			'PERCENT_FILE_PREFIX' => 15,
-			'PERCENT_VERBOSE' => 17,
-			'PERCENT_EXPECT' => 16,
-			'PERCENT_NO_LINES' => 14,
-			'PERCENT_TOKEN_TABLE' => 28,
-			"%%" => 29,
-			'PROLOGUE' => 31,
-			'PERCENT_NAME_PREFIX' => 30,
-			'PERCENT_PARSE_PARAM' => 27,
-			'PERCENT_DEFINES' => 23,
-			'PERCENT_LEFT' => 24,
-			'PERCENT_START' => 22
-		},
-		GOTOS => {
-			'precedence_declaration' => 26,
-			'symbol_declaration' => 25,
-			'grammar_declaration' => 19,
-			'declaration' => 10,
-			'precedence_declarator' => 11
+			'' => 31
 		}
 	},
 	{#State 3
-		DEFAULT => 0
-	},
-	{#State 4
-		DEFAULT => -20
-	},
-	{#State 5
-		DEFAULT => -16
-	},
-	{#State 6
-		DEFAULT => -11
-	},
-	{#State 7
 		ACTIONS => {
-			'BRACED_CODE' => 32
+			'INT' => 32
 		}
 	},
-	{#State 8
+	{#State 4
 		DEFAULT => -7
 	},
+	{#State 5
+		DEFAULT => -6
+	},
+	{#State 6
+		ACTIONS => {
+			'IDENT' => 37,
+			'TYPE' => 36
+		},
+		GOTOS => {
+			'ID' => 35,
+			'symbol_defs_1' => 34,
+			'symbol_def' => 33
+		}
+	},
+	{#State 7
+		DEFAULT => -18
+	},
+	{#State 8
+		DEFAULT => -30
+	},
 	{#State 9
 		ACTIONS => {
-			'TYPE' => 33
+			'EQUAL' => 38
 		}
 	},
 	{#State 10
-		DEFAULT => -4
+		DEFAULT => -19
 	},
 	{#State 11
 		ACTIONS => {
-			'TYPE' => 34
-		},
-		DEFAULT => -32,
-		GOTOS => {
-			'type_opt' => 35
-		}
-	},
-	{#State 12
-		DEFAULT => -30
-	},
-	{#State 13
-		DEFAULT => -31
-	},
-	{#State 14
-		DEFAULT => -13
-	},
-	{#State 15
-		ACTIONS => {
-			'EQUAL' => 36
-		}
-	},
-	{#State 16
-		ACTIONS => {
-			'INT' => 37
-		}
-	},
-	{#State 17
-		DEFAULT => -18
-	},
-	{#State 18
-		DEFAULT => -14
-	},
-	{#State 19
-		DEFAULT => -5
-	},
-	{#State 20
-		DEFAULT => -19
-	},
-	{#State 21
-		ACTIONS => {
-			'IDENT' => 40,
-			'TYPE' => 41
-		},
-		GOTOS => {
-			'symbol_def' => 42,
-			'symbol_defs_1' => 38,
-			'ID' => 39
-		}
-	},
-	{#State 22
-		ACTIONS => {
-			'STRING' => 46,
-			'IDENT' => 40
-		},
-		GOTOS => {
-			'string_as_id' => 45,
-			'ID' => 43,
-			'symbol' => 44
-		}
-	},
-	{#State 23
-		DEFAULT => -8
-	},
-	{#State 24
-		DEFAULT => -29
-	},
-	{#State 25
-		DEFAULT => -22
-	},
-	{#State 26
-		DEFAULT => -21
-	},
-	{#State 27
-		DEFAULT => -15
-	},
-	{#State 28
-		DEFAULT => -17
-	},
-	{#State 29
-		ACTIONS => {
-			'ID_COLON' => 47,
-			'SEMICOLON' => 51,
-			'ERROR' => 48
+			'ID_COLON' => 41,
+			'ERROR' => 43,
+			'SEMICOLON' => 42
 		},
 		DEFAULT => -2,
 		GOTOS => {
-			'grammar' => 50,
-			'rules_or_grammar_declaration' => 52,
-			'rules' => 49
+			'rules_or_grammar_declaration' => 40,
+			'rules' => 39,
+			'grammar' => 44
 		}
 	},
+	{#State 12
+		DEFAULT => -20
+	},
+	{#State 13
+		DEFAULT => -21
+	},
+	{#State 14
+		DEFAULT => -4
+	},
+	{#State 15
+		DEFAULT => -31
+	},
+	{#State 16
+		ACTIONS => {
+			'TYPE' => 46
+		},
+		DEFAULT => -32,
+		GOTOS => {
+			'type_opt' => 45
+		}
+	},
+	{#State 17
+		DEFAULT => -22
+	},
+	{#State 18
+		ACTIONS => {
+			'BRACED_CODE' => 47
+		}
+	},
+	{#State 19
+		DEFAULT => -17
+	},
+	{#State 20
+		ACTIONS => {
+			'TYPE' => 48
+		}
+	},
+	{#State 21
+		DEFAULT => -15
+	},
+	{#State 22
+		DEFAULT => -29
+	},
+	{#State 23
+		DEFAULT => -14
+	},
+	{#State 24
+		DEFAULT => -11
+	},
+	{#State 25
+		DEFAULT => -13
+	},
+	{#State 26
+		DEFAULT => -16
+	},
+	{#State 27
+		DEFAULT => -8
+	},
+	{#State 28
+		ACTIONS => {
+			'IDENT' => 37,
+			'STRING' => 51
+		},
+		GOTOS => {
+			'ID' => 52,
+			'symbol' => 49,
+			'string_as_id' => 50
+		}
+	},
+	{#State 29
+		DEFAULT => -5
+	},
 	{#State 30
 		ACTIONS => {
 			'EQUAL' => 53
 		}
 	},
 	{#State 31
-		DEFAULT => -6
+		DEFAULT => 0
 	},
 	{#State 32
-		DEFAULT => -24
+		DEFAULT => -9
 	},
 	{#State 33
-		ACTIONS => {
-			'IDENT' => 40,
-			'STRING' => 46
-		},
-		GOTOS => {
-			'ID' => 43,
-			'symbol' => 55,
-			'string_as_id' => 45,
-			'symbols_1' => 54
-		}
+		DEFAULT => -40
 	},
 	{#State 34
-		DEFAULT => -33
+		ACTIONS => {
+			'IDENT' => 37
+		},
+		DEFAULT => -25,
+		GOTOS => {
+			'ID' => 35,
+			'symbol_def' => 54
+		}
 	},
 	{#State 35
 		ACTIONS => {
-			'STRING' => 46,
-			'IDENT' => 40
+			'INT' => 55,
+			'STRING' => 51
 		},
+		DEFAULT => -36,
 		GOTOS => {
-			'symbol' => 55,
-			'ID' => 43,
-			'symbols_1' => 56,
-			'string_as_id' => 45
+			'string_as_id' => 56
 		}
 	},
 	{#State 36
 		ACTIONS => {
-			'STRING' => 57
+			'IDENT' => 37
+		},
+		GOTOS => {
+			'symbol_def' => 33,
+			'symbol_defs_1' => 57,
+			'ID' => 35
+		}
+	},
+	{#State 37
+		DEFAULT => -64
+	},
+	{#State 38
+		ACTIONS => {
+			'STRING' => 59
 		},
 		GOTOS => {
 			'string_content' => 58
 		}
 	},
-	{#State 37
-		DEFAULT => -9
-	},
-	{#State 38
-		ACTIONS => {
-			'IDENT' => 40
-		},
-		DEFAULT => -25,
-		GOTOS => {
-			'symbol_def' => 59,
-			'ID' => 39
-		}
-	},
 	{#State 39
-		ACTIONS => {
-			'STRING' => 46,
-			'INT' => 61
-		},
-		DEFAULT => -36,
-		GOTOS => {
-			'string_as_id' => 60
-		}
+		DEFAULT => -44
 	},
 	{#State 40
-		DEFAULT => -64
+		DEFAULT => -42
 	},
 	{#State 41
-		ACTIONS => {
-			'IDENT' => 40
-		},
+		DEFAULT => -51,
 		GOTOS => {
-			'symbol_def' => 42,
-			'symbol_defs_1' => 62,
-			'ID' => 39
+			'rhses_1' => 60,
+			'rhs' => 61
 		}
 	},
 	{#State 42
-		DEFAULT => -40
+		DEFAULT => -47
 	},
 	{#State 43
-		DEFAULT => -55
-	},
-	{#State 44
-		DEFAULT => -23
-	},
-	{#State 45
-		DEFAULT => -56
-	},
-	{#State 46
-		DEFAULT => -60
-	},
-	{#State 47
-		DEFAULT => -51,
-		GOTOS => {
-			'rhses_1' => 63,
-			'rhs' => 64
-		}
-	},
-	{#State 48
 		ACTIONS => {
-			'SEMICOLON' => 65,
-			'IDENT' => 40,
-			'STRING' => 46
+			'IDENT' => 37,
+			'STRING' => 51,
+			'SEMICOLON' => 62
 		},
 		GOTOS => {
-			'ID' => 43,
-			'symbol' => 66,
-			'string_as_id' => 45
+			'string_as_id' => 50,
+			'symbol' => 63,
+			'ID' => 52
 		}
 	},
-	{#State 49
-		DEFAULT => -44
-	},
-	{#State 50
+	{#State 44
 		ACTIONS => {
-			'SEMICOLON' => 51,
-			'ID_COLON' => 47,
-			'ERROR' => 48,
-			"%%" => 69
+			'ERROR' => 43,
+			"%%" => 64,
+			'SEMICOLON' => 42,
+			'ID_COLON' => 41
 		},
 		DEFAULT => -62,
 		GOTOS => {
-			'rules_or_grammar_declaration' => 68,
-			'rules' => 49,
-			'epilogue_opt' => 67
+			'epilogue_opt' => 66,
+			'rules' => 39,
+			'rules_or_grammar_declaration' => 65
 		}
 	},
+	{#State 45
+		ACTIONS => {
+			'IDENT' => 37,
+			'STRING' => 51
+		},
+		GOTOS => {
+			'symbol' => 67,
+			'symbols_1' => 68,
+			'string_as_id' => 50,
+			'ID' => 52
+		}
+	},
+	{#State 46
+		DEFAULT => -33
+	},
+	{#State 47
+		DEFAULT => -24
+	},
+	{#State 48
+		ACTIONS => {
+			'IDENT' => 37,
+			'STRING' => 51
+		},
+		GOTOS => {
+			'symbol' => 67,
+			'symbols_1' => 69,
+			'string_as_id' => 50,
+			'ID' => 52
+		}
+	},
+	{#State 49
+		DEFAULT => -23
+	},
+	{#State 50
+		DEFAULT => -56
+	},
 	{#State 51
-		DEFAULT => -47
+		DEFAULT => -60
 	},
 	{#State 52
-		DEFAULT => -42
+		DEFAULT => -55
 	},
 	{#State 53
 		ACTIONS => {
-			'STRING' => 57
+			'STRING' => 59
 		},
 		GOTOS => {
 			'string_content' => 70
 		}
 	},
 	{#State 54
-		ACTIONS => {
-			'STRING' => 46,
-			'IDENT' => 40
-		},
-		DEFAULT => -27,
-		GOTOS => {
-			'symbol' => 71,
-			'ID' => 43,
-			'string_as_id' => 45
-		}
+		DEFAULT => -41
 	},
 	{#State 55
-		DEFAULT => -34
-	},
-	{#State 56
 		ACTIONS => {
-			'IDENT' => 40,
-			'STRING' => 46
+			'STRING' => 51
 		},
-		DEFAULT => -28,
+		DEFAULT => -37,
 		GOTOS => {
-			'string_as_id' => 45,
-			'symbol' => 71,
-			'ID' => 43
+			'string_as_id' => 71
 		}
 	},
+	{#State 56
+		DEFAULT => -38
+	},
 	{#State 57
-		DEFAULT => -61
+		ACTIONS => {
+			'IDENT' => 37
+		},
+		DEFAULT => -26,
+		GOTOS => {
+			'ID' => 35,
+			'symbol_def' => 54
+		}
 	},
 	{#State 58
 		DEFAULT => -10
 	},
 	{#State 59
-		DEFAULT => -41
+		DEFAULT => -61
 	},
 	{#State 60
-		DEFAULT => -38
-	},
-	{#State 61
 		ACTIONS => {
-			'STRING' => 46
-		},
-		DEFAULT => -37,
-		GOTOS => {
-			'string_as_id' => 72
-		}
-	},
-	{#State 62
-		ACTIONS => {
-			'IDENT' => 40
-		},
-		DEFAULT => -26,
-		GOTOS => {
-			'ID' => 39,
-			'symbol_def' => 59
-		}
-	},
-	{#State 63
-		ACTIONS => {
-			'PIPE' => 73
+			'PIPE' => 72
 		},
 		DEFAULT => -48
 	},
-	{#State 64
+	{#State 61
 		ACTIONS => {
-			'PERCENT_PREC' => 76,
-			'STRING' => 46,
-			'BRACED_CODE_WITH_BRACED_CODE_FOLLOWING' => 77,
+			'BRACED_CODE_WITH_BRACED_CODE_FOLLOWING' => 74,
+			'IDENT' => 37,
+			'STRING' => 51,
 			'BRACED_CODE' => -57,
-			'IDENT' => 40
+			'PERCENT_PREC' => 75
 		},
 		DEFAULT => -49,
 		GOTOS => {
-			'string_as_id' => 45,
-			'ID' => 43,
-			'action_opt' => 75,
-			'symbol' => 74
+			'symbol' => 76,
+			'string_as_id' => 50,
+			'action_opt' => 73,
+			'ID' => 52
+		}
+	},
+	{#State 62
+		DEFAULT => -46
+	},
+	{#State 63
+		ACTIONS => {
+			'SEMICOLON' => 77
+		}
+	},
+	{#State 64
+		ACTIONS => {
+			'EPILOGUE' => 78
 		}
 	},
 	{#State 65
-		DEFAULT => -46
+		DEFAULT => -43
 	},
 	{#State 66
-		ACTIONS => {
-			'SEMICOLON' => 78
-		}
-	},
-	{#State 67
 		DEFAULT => -1
 	},
+	{#State 67
+		DEFAULT => -34
+	},
 	{#State 68
-		DEFAULT => -43
+		ACTIONS => {
+			'IDENT' => 37,
+			'STRING' => 51
+		},
+		DEFAULT => -28,
+		GOTOS => {
+			'ID' => 52,
+			'string_as_id' => 50,
+			'symbol' => 79
+		}
 	},
 	{#State 69
 		ACTIONS => {
-			'EPILOGUE' => 79
+			'IDENT' => 37,
+			'STRING' => 51
+		},
+		DEFAULT => -27,
+		GOTOS => {
+			'ID' => 52,
+			'symbol' => 79,
+			'string_as_id' => 50
 		}
 	},
 	{#State 70
 		DEFAULT => -12
 	},
 	{#State 71
-		DEFAULT => -35
-	},
-	{#State 72
 		DEFAULT => -39
 	},
-	{#State 73
+	{#State 72
 		DEFAULT => -51,
 		GOTOS => {
 			'rhs' => 80
 		}
 	},
+	{#State 73
+		ACTIONS => {
+			'BRACED_CODE' => 82
+		},
+		GOTOS => {
+			'action' => 81
+		}
+	},
 	{#State 74
-		DEFAULT => -52
+		DEFAULT => -58
 	},
 	{#State 75
 		ACTIONS => {
-			'BRACED_CODE' => 81
+			'IDENT' => 37,
+			'STRING' => 51
 		},
 		GOTOS => {
-			'action' => 82
+			'symbol' => 83,
+			'string_as_id' => 50,
+			'ID' => 52
 		}
 	},
 	{#State 76
-		ACTIONS => {
-			'IDENT' => 40,
-			'STRING' => 46
-		},
-		GOTOS => {
-			'string_as_id' => 45,
-			'ID' => 43,
-			'symbol' => 83
-		}
+		DEFAULT => -52
 	},
 	{#State 77
-		DEFAULT => -58
-	},
-	{#State 78
 		DEFAULT => -45
 	},
-	{#State 79
+	{#State 78
 		DEFAULT => -63
 	},
+	{#State 79
+		DEFAULT => -35
+	},
 	{#State 80
 		ACTIONS => {
+			'PERCENT_PREC' => 75,
 			'BRACED_CODE' => -57,
-			'IDENT' => 40,
-			'BRACED_CODE_WITH_BRACED_CODE_FOLLOWING' => 77,
-			'PERCENT_PREC' => 76,
-			'STRING' => 46
+			'IDENT' => 37,
+			'STRING' => 51,
+			'BRACED_CODE_WITH_BRACED_CODE_FOLLOWING' => 74
 		},
 		DEFAULT => -50,
 		GOTOS => {
-			'action_opt' => 75,
-			'symbol' => 74,
-			'ID' => 43,
-			'string_as_id' => 45
+			'ID' => 52,
+			'action_opt' => 73,
+			'symbol' => 76,
+			'string_as_id' => 50
 		}
 	},
 	{#State 81
-		DEFAULT => -59
+		DEFAULT => -53
 	},
 	{#State 82
-		DEFAULT => -53
+		DEFAULT => -59
 	},
 	{#State 83
 		DEFAULT => -54
@@ -1234,7 +1234,7 @@ sub _Lexer {
         return($1, [ $1, $lineno[0] ]);
     };
 
-        $$input=~/\G{/gc
+        $$input=~/\G\{/gc
     and do {
         my $code;
 
@@ -1286,7 +1286,7 @@ sub _Lexer {
         # Lookahead to resolve shift/reduce error
         {
           my $old_pos = pos $$input;
-          if ($$input =~ /\G\s*{/)
+          if ($$input =~ /\G\s*\{/)
           {
             pos $$input = $old_pos;
             return('BRACED_CODE_WITH_BRACED_CODE_FOLLOWING',[ $code, $lineno[0] ]);
@@ -1310,7 +1310,7 @@ sub _Lexer {
         and return('PERCENT_START',[ undef, $lineno[0] ]);
             $$input=~/\G%(expect)/gc
         and return('PERCENT_EXPECT',[ undef, $lineno[0] ]);
-            $$input=~/\G%{/gc
+            $$input=~/\G%\{/gc
         and do {
             my($code);
 
